@@ -1,7 +1,7 @@
 #
 #       plot.fv.R   (was: conspire.S)
 #
-#  $Revision: 1.143 $    $Date: 2024/02/04 08:04:51 $
+#  $Revision: 1.146 $    $Date: 2025/12/26 02:55:58 $
 #
 #
 
@@ -57,7 +57,7 @@ plot.fv <- local({
                       shade=fvnames(x, ".s"), shadecol="grey", add=FALSE,
                       log="",
                       mathfont=c("italic", "plain", "bold", "bolditalic"), 
-                      limitsonly=FALSE) {
+                      limitsonly=FALSE, do.plot=TRUE) {
 
     xname <-
       if(is.language(substitute(x))) short.deparse(substitute(x)) else ""
@@ -140,8 +140,8 @@ plot.fv <- local({
     rhs <- fmla[[3]]
 
     ## extract data 
-    lhsdata <- eval(lhs, envir=indata)
-    rhsdata <- eval(rhs, envir=indata)
+    lhsdata <- eval(lhs, envir=indata, enclos=env.user)
+    rhsdata <- eval(rhs, envir=indata, enclos=env.user)
 
     ## reformat
     if(is.vector(lhsdata)) {
@@ -211,7 +211,7 @@ plot.fv <- local({
                                  list(fom=fmla.original)))
           dont.complain.about(u, ux, uy)
           lhsnew <- foo[[2]]
-          morelhs <- eval(lhsnew, envir=indata)
+          morelhs <- eval(lhsnew, envir=indata, enclos=env.user)
           success <- identical(colnames(morelhs), extrashadevars)
         } else if(is.name(lhs) && as.character(lhs) %in% names(indata)) {
           ## lhs is the name of a single column in x
@@ -268,8 +268,8 @@ plot.fv <- local({
     ## restrict data to subset if desired
     if(!is.null(subset)) {
       keep <- if(is.character(subset)) {
-                eval(parse(text=subset), envir=indata)
-              } else eval(subset, envir=indata)
+                eval(parse(text=subset), envir=indata, enclos=env.user)
+              } else eval(subset, envir=indata, enclos=env.user)
       lhsdata <- lhsdata[keep, , drop=FALSE]
       rhsdata <- rhsdata[keep]
     }
@@ -416,8 +416,10 @@ plot.fv <- local({
 
     ## ------------------ start plotting ---------------------------
 
+    do.plot <- isTRUE(do.plot)
+    
     ## create new plot
-    if(!add)
+    if(do.plot && !add)
       do.call(plot.default,
               resolve.defaults(list(xlim, ylim, type="n", log=log),
                                list(xlab=xlab, ylab=ylab),
@@ -507,9 +509,11 @@ plot.fv <- local({
   
     ## ----------------- plot lines ------------------------------
 
-    for(i in allind) {
-      clip.to.usr(xlogscale, ylogscale)
-      lines(rhsdata, lhsdata[,i], lty=lty[i], col=col[i], lwd=lwd[i])
+    if(do.plot) {
+      for(i in allind) {
+        clip.to.usr(xlogscale, ylogscale)
+        lines(rhsdata, lhsdata[,i], lty=lty[i], col=col[i], lwd=lwd[i])
+      }
     }
 
     if(nplots == 1)
@@ -555,7 +559,7 @@ plot.fv <- local({
 
     ## --------------- handle legend plotting  -----------------------------
     
-    if(identical(legend, TRUE)) {
+    if(do.plot && isTRUE(legend)) {
       ## legend will be plotted
       ## Basic parameters of legend
       legendxpref <- if(identical(legendpos, "float")) NULL else legendpos
