@@ -1,7 +1,7 @@
 #'
 #'  rhohat.R
 #'
-#'  $Revision: 1.116 $  $Date: 2023/08/14 06:33:10 $
+#'  $Revision: 1.117 $  $Date: 2026/01/21 06:26:39 $
 #'
 #'  Non-parametric estimation of a function rho(z) determining
 #'  the intensity function lambda(u) of a point process in terms of a
@@ -698,7 +698,7 @@ rhohatCalc <- local({
       fvnames(rslt, ".s") <- c("hi", "lo")
     } else fvnames(rslt, ".")  <- c("rho", "ave")
     ## pack up
-    class(rslt) <- c("rhohat", class(rslt))
+    class(rslt) <- unique(c("rhohat", class(rslt)))
     ## add info
     stuff <- 
       list(modelcall  = modelcall, 
