@@ -3,7 +3,7 @@
 ##
 ## Exact 'funxy' counterpart of Smooth.ppp
 ##
-##  $Revision: 1.11 $ $Date: 2023/04/01 02:25:41 $
+##  $Revision: 1.12 $ $Date: 2026/01/21 06:26:39 $
 
 
 Smoothfun <- function(X, ...) {
@@ -49,7 +49,7 @@ Smoothfun.ppp <- function(X, sigma=NULL, ...,
     do.call(smoothcrossEngine, append(list(Xquery=Xquery), stuff))
   }
   g <- funxy(g, as.rectangle(as.owin(X)))
-  class(g) <- c("Smoothfun", class(g))
+  class(g) <- unique(c("Smoothfun", class(g)))
   return(g)
 }
 
